# Pingline - a less cool, matplotlib version of [gping](https://github.com/orf/gping)

This is just a package for me to practice working with PyPi. It's not unique and you should probably use [gping](https://github.com/orf/gping) instead.

### Installation

```
pip install pingline
```
